@@ -22,13 +22,16 @@ class IdentityKey(models.Model):
     keyId = models.IntegerField()
     public = models.CharField(max_length=44)
     localId = models.IntegerField()
-    user = models.ForeignKey(User, on_delete=models.CASCADE, related_name='identityKeys')
+    # user = models.ForeignKey(User, on_delete=models.CASCADE, related_name='identityKeys')
     cipher = models.CharField(max_length=88)
     salt = models.CharField(max_length=44)
     active = models.BooleanField(default=False)
     timestamp = models.CharField(max_length=100)
     dt_timestamp = models.DateTimeField(auto_now_add=True)
 
+    # class Meta:
+    #     constraints = [models.UniqueConstraint(fields=['keyId', 'user'], name='unique_identity_key')]
+
 
 class SignedPreKey(models.Model):
     """
